@@ -25,6 +25,22 @@ class Cliente(core.models.Log, core.models.PessoaLog):
         db_table = 'cliente'
 
 
+class Contato(core.models.Log):
+    cliente = models.ForeignKey('cliente.Cliente', on_delete=models.DO_NOTHING, null=True)
+    valor = models.CharField(max_length=200, null=True)
+
+    tipo_codigo = models.CharField(null=True, max_length=200)
+    tipo_tipo = models.CharField(null=True, max_length=200, default='CLIENTE.CONTATO')
+    tipo = CompositeForeignKey('core.Tipo', on_delete=models.DO_NOTHING, null=True, related_name='cliente_contato', to_fields={
+        "codigo": "tipo_codigo",
+        "tipo": "tipo_tipo"
+    })
+
+    class Meta(core.models.Log.Meta):
+        abstract = False
+        db_table = 'cliente_contato'
+
+
 class Endereco(core.models.Log, core.models.EnderecoComplementoLog):
     """
     :Nome da classe/função: Endereco
@@ -88,8 +104,8 @@ class Cartao(core.models.Log):
     adquirente_codigo = models.CharField(null=True, max_length=200)
     adquirente_tipo = models.CharField(null=True, max_length=200, default='CLIENTE.CARTAO.ADQUIRENTE')
     adquirente = CompositeForeignKey('core.Tipo', on_delete=models.DO_NOTHING, null=True, related_name='cliente_cartao_adquirente', to_fields={
-        "codigo": "tipo_codigo",
-        "tipo": "tipo_tipo"
+        "codigo": "adquirente_codigo",
+        "tipo": "adquirente_tipo"
     })
 
     class Meta(core.models.Log.Meta):
